@@ -1,6 +1,5 @@
 __all__ = ('LoanPoint', 'LoanObjectPoint', 'ClosedLoanPoint', 'ClosedLoanObjectPoint', 'LoanPaymentPoint',
-           'ExportPoint',
-           )
+           'ExportPoint', 'PartialLoanPaymentPoint', 'ExtendLoanPoint')
 
 from typing import OrderedDict, Union
 
@@ -140,6 +139,15 @@ class ExportReadContract(Contract):
     status = serializers.ChoiceField(choices=STATUS_CHOICES)
 
 
+class ExtendLoanCreateContract(Contract):
+    pass
+
+
+class PartialPaymentContract(Contract):
+    bank_card_id = serializers.IntegerField(min_value=1)
+    amount = serializers.DecimalField(max_digits=16, decimal_places=0)
+
+
 class LoanID(ID):
     _service = SERVICE
     _app = 'loans'
@@ -164,6 +172,18 @@ class ExportID(ID):
     _view_set = 'export'
 
 
+class ExtendLoanID(ID):
+    _service = SERVICE
+    _app = 'loans'
+    _view_set = 'set_extended'
+
+
+class PartialPaymentID(ID):
+    _service = SERVICE
+    _app = 'loans'
+    _view_set = 'partial_payment'
+
+
 class LoanPoint(ListPointMixin, CreatePointMixin, ContractPoint):
     _point_id = LoanID()
     _read_contract = LoanReadContract
@@ -202,3 +222,13 @@ class ExportPoint(ListPointMixin, ContractPoint):
     _point_id = ExportID()
     _read_contract = ExportReadContract
     _cache_enabled = False
+
+
+class ExtendLoanPoint(CreatePointMixin, ContractPoint):
+    _point_id = ExtendLoanID()
+    _create_contract = ExtendLoanCreateContract
+
+
+class PartialLoanPaymentPoint(CreatePointMixin, ContractPoint):
+    _point_id = PartialPaymentID()
+    _create_contract = PartialPaymentContract
