@@ -9,7 +9,7 @@ APP = 'pdl_ru_v1'
 
 class ScoreCreateContract(Contract):
     order_id = serializers.IntegerField(min_value=1, allow_null=True)
-    em_amount_requested = serializers.IntegerField(min_value=1, allow_null=True)
+    em_amount_requested = serializers.IntegerField(min_value=1)
 
 
 class ScoreResponseContract(Contract):
